// CodeMirror
import 'codemirror/mode/jsx/jsx';
import 'codemirror/lib/codemirror.css';
import 'rsg-codemirror-theme.css';

// Styleguidist reqs
import React, { Component, PropTypes } from 'react';
import debounce from 'lodash/debounce';
import Codemirror from 'react-codemirror';
import EditorRenderer from 'react-styleguidist/src/rsg-components/Editor/EditorRenderer';

// styles
import './index.css';

const codemirrorOptions = {
  mode: 'jsx',
  lineNumbers: false,
  lineWrapping: true,
  smartIndent: false,
  matchBrackets: true,
  viewportMargin: Infinity,
};

const UPDATE_DELAY = 10;

class Editor extends Component {
  constructor(props) {
    super(props);
    this.handleChange = debounce(this.handleChange.bind(this), UPDATE_DELAY);
  }

  shouldComponentUpdate() {
    return false;
  }

  handleChange(newCode) {
    this.props.onChange(newCode);
  }

  render() {
    let { code } = this.props;
    const { highlightTheme } = this.context.config;
    const options = {
      ...codemirrorOptions,
      theme: highlightTheme
    };

    // Trigger change of code by adding a character the the area
    return (
      <div className='qb-editor'>
        <button className='qb-refresh' onClick={ () => { this.handleChange(code += ' '); } }>RERUN</button>
        <EditorRenderer>
          <Codemirror value={code} onChange={this.handleChange} options={options} />
        </EditorRenderer>
      </div>
    );
  }
}

Editor.propTypes = {
  code: PropTypes.string.isRequired,
  onChange: PropTypes.func.isRequired
};

Editor.contextTypes = {
  config: PropTypes.object.isRequired
};

export default Editor;
