import React, { PropTypes } from 'react';
import classnames from 'classnames';

const s = require('react-styleguidist/src/rsg-components/ReactComponent/ReactComponent.css');

const ReactComponentRenderer = ({ name, pathLine, description, props, examples, sidebar }) => {

  const str = description ? description.props.text : '';
  const isAnimated = /\(ANIMATED\)/.test(str);

  return (
    <div className={ classnames(s.root, { 'is-animated': isAnimated }) } id={ name }>
      <div className={ s.meta }>
        <header className={ s.header }>
          <a className={ s.anchor } href={ '#' + name }>
            <h2 className={ s.heading }>{ name }</h2>
          </a>
          <div className={ s.description }>
            { description }
          </div>
          <p className={ s.pathLine }>
            {sidebar ? (
              <a className={ s.isolatedLink } href={'#!/' + name} title="Open isolated">⇢</a>
            ) : (
              <a className={ s.isolatedLink } href="/" title="Back">←</a>
            )}
            {pathLine}
          </p>
        </header>
        <div className={ s.props }>
          { props }
        </div>
      </div>
      { examples && (
        <div className={ s.examples }>
          { examples }
        </div>
        )
      }
    </div>
  );
};

ReactComponentRenderer.propTypes = {
  name: PropTypes.string.isRequired,
  pathLine: PropTypes.string.isRequired,
  description: PropTypes.node,
  props: PropTypes.node,
  examples: PropTypes.node,
  sidebar: PropTypes.bool,
};

export default ReactComponentRenderer;
